""""""

import irt_parameter_estimation


def test_1():
    pass


if __name__ == "__main__":
    test_1()
